@@ -71,7 +71,6 @@ def parse_cmd(in_str):
                 nums.append(int(each))
         except:
             # fixes trailing commas and inputs like `,,,` `#,#,#`
-            # TODO: fix `#,3`
             if(len(each) < 1 or each == '#'):
                 continue
             # if multiple #'s are there, then it should be invalid
@@ -89,6 +88,8 @@ def parse_cmd(in_str):
         action = constants.parser_actions.LIST_QUESTIONS_OF_TAGS
     if(len(tags) == 0):
         action = constants.parser_actions.OPEN_QUESTIONS
+    if(len(tags) == 0 and len(nums) == 0):
+        action = constants.parser_actions.DO_NOTHING
     d(print, f'error: {error}')
     d(print, f'nums: {nums}')
     d(print, f'tags: {tags}')
